@@ -26,6 +26,7 @@ G_BEGIN_DECLS
 
 #include "hdy-version.h"
 #include "hdy-action-row.h"
+#include "hdy-animation.h"
 #include "hdy-arrows.h"
 #include "hdy-column.h"
 #include "hdy-combo-row.h"
@@ -36,11 +37,18 @@ G_BEGIN_DECLS
 #include "hdy-enum-value-object.h"
 #include "hdy-expander-row.h"
 #include "hdy-fold.h"
+#include "hdy-header-bar.h"
 #include "hdy-header-group.h"
 #include "hdy-leaflet.h"
 #include "hdy-list-box.h"
 #include "hdy-main.h"
+#include "hdy-paginator.h"
+#include "hdy-preferences-group.h"
+#include "hdy-preferences-page.h"
+#include "hdy-preferences-row.h"
+#include "hdy-preferences-window.h"
 #include "hdy-search-bar.h"
+#include "hdy-squeezer.h"
 #include "hdy-string-utf8.h"
 #include "hdy-title-bar.h"
 #include "hdy-value-object.h"
